/*
 * @Author: tzw
 * @Date: 2021-10-31 23:26:50
 * @LastEditors: tzw
 * @LastEditTime: 2021-11-03 23:21:38
 */
use std::collections::HashMap;
use serde::{Deserialize, Serialize};

/**
eventuate 消息定义
*/
pub trait Imessage{
     fn get_id(&self) -> Option<String>;
     fn get_headers(&self) -> Option<HashMap<String, String>>;
     fn get_payload(&self)-> Option<String>;
     fn get_header(&self, name: &str)-> Option<String>;
     fn get_required_header(&self, name: &str)-> String;
     fn has_header(&self, name: &str)-> bool;
}

#[derive(Serialize, Deserialize,Clone, Debug)]
pub struct MessageImpl{
    pub payload: Option<String>,
    pub headers: Option<HashMap<String, String>>,
}


impl Imessage for MessageImpl {
    fn get_id(&self) -> Option<String> {
        todo!()
    }

    fn get_headers(&self) -> Option<HashMap<String, String>> {
        todo!()
    }

    fn get_payload(&self)-> Option<String> {
        todo!()
    }

    fn get_header(&self, name: &str)-> Option<String> {
        todo!()
    }

    fn get_required_header(&self, name: &str)-> String {
        todo!()
    }

    fn has_header(&self, name: &str)-> bool {
        todo!()
    }
}